Welcome to Flask-WaffleConf's documentation!
============================================

WaffleConf is a Flask extension that enables storage of configuration variables
in the database as well as runtime modification of said variables.

**Released under GPLv2+ license.**

Latest version: **0.3.0**

Contents:

.. toctree::
   :hidden:

   self

.. toctree::
   :maxdepth: 1

   quickstart
   configuration
   multiproc
   usage

.. toctree::
   :maxdepth: 4

   flask_waffleconf


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

